﻿using Exam.Application.Interface.Exam;
using Exam.Application.Interface.TestPapers;
using Exam.Infrastructure.Data.Entity;
using Exam.Share.ViewResponses.Exam;
using Exam.Share.ViewResponses.TestPaper;
using Hotline.Application.Exam.Constants.ApiRoutes;
using Hotline.Share.Dtos.Questions;
using Hotline.Share.Dtos.TestPapers;
using Hotline.Share.Requests.Exam;
using Hotline.Share.Requests.TestPaper;
using Hotline.Share.ViewResponses.Exam;
using Hotline.Share.ViewResponses.Questions;
using Microsoft.AspNetCore.Mvc;

namespace Hotline.Api.Controllers.Exam
{
    public class TestPaperController : BaseController
    {
        private readonly ITestPaperService _testPaperService;
        public TestPaperController(ITestPaperService testPaperService)
        {
            _testPaperService = testPaperService;
        }

        /// <summary>
        /// 新增试卷
        /// </summary>
        /// <param name="extractRuleDto"></param>
        /// <returns></returns>
        [HttpPost(TestPaperApiRoute.Add)]
        public async Task Add([FromBody] AddTestPaperDto extractRuleDto)
        {
            await _testPaperService.AddAsync(extractRuleDto, HttpContext.RequestAborted);
        }

        /// <summary>
        /// 修改试卷
        /// </summary>
        /// <param name="extractRuleDto"></param>
        /// <returns></returns>
        [HttpPut(TestPaperApiRoute.Update)]
        public async Task Update([FromBody] UpdateTestPaperDto extractRuleDto)
        {
            await _testPaperService.UpdateAsync(extractRuleDto, HttpContext.RequestAborted);
        }

        /// <summary>
        /// 删除试卷
        /// </summary>
        /// <param name="entityQueryRequest"></param>
        /// <returns></returns>
        [HttpDelete(TestPaperApiRoute.Delete)]

        public async Task Delete(EntityQueryRequest entityQueryRequest)
        {
            await _testPaperService.DeleteAsync(entityQueryRequest, HttpContext.RequestAborted);
        }

        /// <summary>
        /// 获取课件分页列表
        /// </summary>
        /// <param name="sourcewarePagedRequest"></param>
        /// <returns></returns>
        [HttpPost(TestPaperApiRoute.GetPagedList)]
        public async Task<TestPaperPageViewResponse> GetPagedList([FromBody] TestPaperPagedRequest sourcewarePagedRequest)
        {
            var testPaperPageViewResponse = await _testPaperService.GetPagedListAsync(sourcewarePagedRequest);

            return testPaperPageViewResponse as TestPaperPageViewResponse;
        }


        /// <summary>
        /// 获取课件分类
        /// </summary>
        /// <param name="id"></param>
        /// <returns></returns>
        [HttpGet(TestPaperApiRoute.Get)]
        public async Task<TestPaperDto> Get(string id)
        {
            var testPaperDto = await _testPaperService.GetAsync(new EntityQueryRequest
            {
                Id = id
            });

            return testPaperDto;
        }

        /// <summary>
        /// 获取试卷试题数
        /// </summary>
        /// <returns></returns>
        [HttpGet(TestPaperApiRoute.Count)]
        public async Task<List<TestPaperQuestionCountViewResponse>> GetPagedList([FromQuery] TestPaperQuestionCountRequest testPaperQuestionCountRequest)
        {
            var testPaperQuestionCountViewResponses = await _testPaperService.GetTestPaperQuestionCount(testPaperQuestionCountRequest);

            return testPaperQuestionCountViewResponses;
        }

        /// <summary>
        /// 根据规则获取试题
        /// </summary>
        /// <param name="testPaperQuestionRequest"></param>
        /// <returns></returns>
        [HttpPost(TestPaperApiRoute.GetQuestions)]
        public async Task<List<SimpleQuestionViewResponse>> GetQuestions([FromBody]TestPaperQuestionRequest testPaperQuestionRequest)
        {
           return await _testPaperService.GetQuestionDtos(testPaperQuestionRequest);
        }

        /// <summary>
        /// 获取标签试题数
        /// </summary>
        /// <param name="tagQuestionCountRequest"></param>
        /// <returns></returns>
        [HttpPost(TestPaperApiRoute.GetTagQuestionCount)]
        public async Task<TagQuestionCountViewResponse> GetTagQuestionCount([FromBody] TagQuestionCountRequest tagQuestionCountRequest)
        {
            return await _testPaperService.GetTagQuestionCount(tagQuestionCountRequest);
        }
    }
}
